@@ -3,11 +3,11 @@ BEGIN {
   $POE::Component::IRC::Common::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Common::VERSION = '6.35';
+  $POE::Component::IRC::Common::VERSION = '6.54';
 }
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 
 use Encode qw(decode);
 use Encode::Guess;
@@ -27,14 +27,14 @@ my ($ERROR, $ERRNO);
 
 use constant {
     NORMAL      => "\x0f",
-    
+
     # formatting
     BOLD        => "\x02",
     UNDERLINE   => "\x1f",
     REVERSE     => "\x16",
     ITALIC      => "\x1d",
     FIXED       => "\x11",
-    
+
     # mIRC colors
     WHITE       => "\x0300",
     BLACK       => "\x0301",
@@ -99,7 +99,7 @@ sub parse_mode_line {
     my $statmodes = 'ov';
     my $hashref = { };
     my $count = 0;
-    
+
     while (my $arg = shift @args) {
         if ( ref $arg eq 'ARRAY' ) {
            $chanmodes = $arg;
@@ -109,7 +109,7 @@ sub parse_mode_line {
            $statmodes = join '', keys %{ $arg };
            next;
         }
-        elsif ( $arg =~ /^(\+|-)/ or $count == 0 ) {
+        elsif ( $arg =~ /^[-+]/ or $count == 0 ) {
             my $action = '+';
             for my $char ( split (//,$arg) ) {
                 if ($char eq '+' or $char eq '-') {
@@ -118,12 +118,13 @@ sub parse_mode_line {
                 else {
                    push @{ $hashref->{modes} }, $action . $char;
                 }
-                
-                if ($char =~ /[$statmodes$chanmodes->[0]$chanmodes->[1]]/) {
+
+                if (length $chanmodes->[0] && length $chanmodes->[1] && length $statmodes
+                    && $char =~ /[$statmodes$chanmodes->[0]$chanmodes->[1]]/) {
                     push @{ $hashref->{args} }, shift @args;
                 }
-                
-                if ($action eq '+' && $char =~ /[$chanmodes->[2]]/) {
+
+                if (length $chanmodes->[2] && $action eq '+' && $char =~ /[$chanmodes->[2]]/) {
                     push @{ $hashref->{args} }, shift @args;
                 }
             }
@@ -150,26 +151,26 @@ sub parse_ban_mask {
     else {
         ($ban[0], $remainder) = split /\x21/, $arg, 2;
     }
-    
+
     $remainder =~ s/\x21//g if defined $remainder;
     @ban[1..2] = split(/\x40/, $remainder, 2) if defined $remainder;
     $ban[2] =~ s/\x40//g if defined $ban[2];
-    
+
     for my $i (1..2) {
         $ban[$i] = '*' if !$ban[$i];
     }
-    
+
     return $ban[0] . '!' . $ban[1] . '@' . $ban[2];
 }
 
 sub matches_mask_array {
     my ($masks, $matches, $mapping) = @_;
-    
+
     return if !defined $masks || !defined $matches;
     return if ref $masks ne 'ARRAY';
     return if ref $matches ne 'ARRAY';
     my $ref = { };
-    
+
     for my $mask ( @{ $masks } ) {
         for my $match ( @{ $matches } ) {
             if ( matches_mask($mask, $match, $mapping) ) {
@@ -177,7 +178,7 @@ sub matches_mask_array {
             }
         }
     }
-    
+
     return $ref;
 }
 
@@ -223,14 +224,14 @@ sub has_formatting {
 sub strip_color {
     my ($string) = @_;
     return if !defined $string;
-    
+
     # mIRC colors
     $string =~ s/\x03(?:,\d{1,2}|\d{1,2}(?:,\d{1,2})?)?//g;
     $string =~ s/\x0f//g;
-    
+
     # RGB colors supported by some clients
     $string =~ s/\x04[0-9a-fA-F]{0,6}//ig;
-    
+
     return $string;
 }
 
@@ -384,7 +385,6 @@ sub irc_ip_is_ipv6 {
 }
 
 1;
-__END__
 
 =encoding utf8
 
@@ -532,7 +532,7 @@ Takes two parameters, a string representing an IRC mask ( it'll be processed
 with parse_ban_mask() to ensure that it is normalised ) and something to match
 against the IRC mask, such as a nick!user@hostname string. Returns a true
 value if they match, a false value otherwise. Optionally, one may pass the
-casemapping (see L<C<u_irc>|/"u_irc">), as this function uses C<u_irc>
+casemapping (see L<C<u_irc>|/u_irc>), as this function uses C<u_irc>
 internally.
 
 =head2 C<matches_mask_array>
@@ -541,7 +541,7 @@ Takes two array references, the first being a list of strings representing
 IRC masks, the second a list of somethings to test against the masks. Returns
 an empty hashref if there are no matches. Otherwise, the keys will be the
 masks matched, each value being an arrayref of the strings that matched it.
-Optionally, one may pass the casemapping (see L<C<u_irc>|/"u_irc">), as
+Optionally, one may pass the casemapping (see L<C<u_irc>|/u_irc>), as
 this function uses C<u_irc> internally.
 
 =head2 C<parse_user>
@@ -581,7 +581,7 @@ always do what you expect it to.
 =head2 C<irc_to_utf8>
 
 This function takes a byte string (e.g. a message from an
-L<C<irc_public>|POE::Component::IRC/"irc_public"> handler) in "IRC encoding"
+L<C<irc_public>|POE::Component::IRC/irc_public> handler) in "IRC encoding"
 and returns a text string. Since the source encoding might have been UTF-8,
 you should encode/store it in UTF-8 or some other Unicode encoding in your
 file/database/whatever.
