@@ -3,11 +3,11 @@ BEGIN {
   $POE::Component::IRC::Constants::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Constants::VERSION = '6.35';
+  $POE::Component::IRC::Constants::VERSION = '6.54';
 }
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 
 require Exporter;
 use base qw(Exporter);
@@ -38,7 +38,6 @@ use constant {
 };
 
 1;
-__END__
 
 =encoding utf8
 
