@@ -1,15 +1,19 @@
 package POE::Component::IRC::Plugin::Proxy;
+BEGIN {
+  $POE::Component::IRC::Plugin::Proxy::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Component::IRC::Plugin::Proxy::VERSION = '6.54';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use Carp;
 use Socket;
-use POE qw(Wheel::SocketFactory Wheel::ReadWrite Filter::IRCD 
+use POE qw(Wheel::SocketFactory Wheel::ReadWrite Filter::IRCD
            Filter::Line Filter::Stackable);
 use POE::Component::IRC::Plugin qw(PCI_EAT_NONE);
 
-our $VERSION = '6.22';
-
 sub new {
     my ($package) = shift;
     croak "$package requires an even number of arguments" if @_ & 1;
@@ -103,17 +107,17 @@ sub S_raw {
     my $input = $self->{irc_filter}->get( [$line] )->[0];
 
     return PCI_EAT_NONE if $input->{command} eq 'PING';
-    
+
     for my $wheel_id (keys %{ $self->{wheels} }) {
         $self->_send_to_client($wheel_id, $line);
     }
 
     return PCI_EAT_NONE if $self->{stashed};
-    
+
     if ($input->{command} =~ /^(?:NOTICE|\d{3})$/) {
         push @{ $self->{stash} }, $line;
     }
-    
+
     $self->{stashed} = 1 if $input->{command} =~ /^(?:376|422)$/;
     return PCI_EAT_NONE;
 }
@@ -122,7 +126,7 @@ sub _send_to_client {
     my ($self, $wheel_id, $line) = splice @_, 0, 3;
     return if !defined $self->{wheels}->{ $wheel_id }->{wheel};
     return if !$self->{wheels}->{ $wheel_id }->{reg};
-    
+
     $self->{wheels}->{ $wheel_id }->{wheel}->put($line);
     return;
 }
@@ -149,7 +153,7 @@ sub _start {
             $self->{irc_filter},
         ],
     );
-    
+
     if ($self->{irc}->connected()) {
         $kernel->yield('_spawn_listener');
     }
@@ -166,13 +170,13 @@ sub _spawn_listener {
         FailureEvent => '_listener_failed',
         Reuse        => 'yes',
     );
-    
+
     if (!$self->{listener}) {
         my $irc = $self->{irc};
         $irc->plugin_del($self);
         return;
     }
-    
+
     $self->{irc}->send_event(irc_proxy_up => $self->{listener}->getsockname());
     return;
 }
@@ -202,7 +206,7 @@ sub _listener_accept {
     else {
         $self->{irc}->send_event(irc_proxy_rw_fail => inet_ntoa( $peeradr ) => $peerport);
     }
-    
+
     return;
 }
 
@@ -314,13 +318,13 @@ sub _shutdown {
 
     my $mysockaddr = $self->getsockname();
     delete $self->{listener};
-    
+
     for my $wheel_id ( $self->list_wheels() ) {
         $self->_close_wheel( $wheel_id );
     }
     delete $self->{wheels};
     $irc->send_event(irc_proxy_down => $mysockaddr);
-    
+
     return;
 }
 
@@ -343,7 +347,8 @@ sub wheel_info {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
@@ -358,8 +363,8 @@ lightweight IRC proxy/bouncer
 
  my $irc = POE::Component::IRC::State->spawn();
 
- POE::Session->create( 
-     package_states => [ 
+ POE::Session->create(
+     package_states => [
          main => [ qw(_start) ],
      ],
      heap => { irc => $irc },
@@ -388,12 +393,12 @@ Spawn a L<POE::Component::IRC::State> session and add in a
 POE::Component::IRC::Plugin::Proxy plugin object, specifying a bindport and a
 password the connecting IRC clients have to use. When the component is
 connected to an IRC network a listening port is opened by the plugin for
-multiple IRC clients to connect. 
+multiple IRC clients to connect.
 
 Neat, huh? >;o)
 
 This plugin will activate L<POE::Component::IRC>'s raw
-events (L<C<irc_raw>|POE::Component::IRC/"irc_raw">) by calling
+events (L<C<irc_raw>|POE::Component::IRC/irc_raw>) by calling
 C<< $irc->raw_events(1) >>.
 
 This plugin requires the IRC component to be
@@ -407,7 +412,7 @@ Takes a number of arguments:
 
 B<'password'>, the password to require from connecting clients;
 
-B<'bindaddr'>, a local address to bind the listener to, default is 'localhost';
+B<'bindaddress'>, a local address to bind the listener to, default is 'localhost';
 
 B<'bindport'>, what port to bind to, default is 0, ie. randomly allocated by OS;
 
