@@ -3,11 +3,11 @@ BEGIN {
   $POE::Component::IRC::State::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::State::VERSION = '6.35';
+  $POE::Component::IRC::State::VERSION = '6.54';
 }
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use POE;
 use POE::Component::IRC::Common qw(u_irc parse_mode_line parse_ban_mask);
 use POE::Component::IRC::Plugin qw(PCI_EAT_NONE);
@@ -20,7 +20,10 @@ use base qw(POE::Component::IRC);
 # Make sure we have a clean STATE when we first join the network and if we
 # inadvertently get disconnected.
 sub S_001 {
-    my ($self) = @_;
+    my $self = shift;
+    $self->SUPER::S_001(@_);
+    shift @_;
+
     delete $self->{STATE};
     delete $self->{NETSPLIT};
     $self->{STATE}{usermode} = '';
@@ -29,33 +32,42 @@ sub S_001 {
 }
 
 sub S_disconnected {
-    my ($self) = @_;
+    my $self = shift;
+    $self->SUPER::S_disconnected(@_);
+    shift @_;
+
     my $nickinfo = $self->nick_info($self->nick_name());
+    $nickinfo = {} if !defined $nickinfo;
     my $channels = $self->channels();
     push @{ $_[-1] }, $nickinfo, $channels;
     return PCI_EAT_NONE;
 }
 
 sub S_error {
-    my ($self) = @_;
+    my $self = shift;
+    $self->SUPER::S_error(@_);
+    shift @_;
+
     my $nickinfo = $self->nick_info($self->nick_name());
+    $nickinfo = {} if !defined $nickinfo;
     my $channels = $self->channels();
     push @{ $_[-1] }, $nickinfo, $channels;
     return PCI_EAT_NONE;
 }
 
 sub S_socketerr {
-    my ($self) = @_;
+    my ($self, undef) = splice @_, 0, 2;
     my $nickinfo = $self->nick_info($self->nick_name());
+    $nickinfo = {} if !defined $nickinfo;
     my $channels = $self->channels();
     push @{ $_[-1] }, $nickinfo, $channels;
     return PCI_EAT_NONE;
 }
 
 sub S_join {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my ($nick, $user, $host) = split /[!@]/, ${ $_[0] };
-    my $map   = $irc->isupport('CASEMAPPING');
+    my $map   = $self->isupport('CASEMAPPING');
     my $chan  = ${ $_[1] };
     my $uchan = u_irc($chan, $map);
     my $unick = u_irc($nick, $map);
@@ -105,12 +117,12 @@ sub S_join {
     $self->{STATE}{Nicks}{ $unick }{Host} = $host;
     $self->{STATE}{Nicks}{ $unick }{CHANS}{ $uchan } = '';
     $self->{STATE}{Chans}{ $uchan }{Nicks}{ $unick } = '';
-    
+
     return PCI_EAT_NONE;
 }
 
 sub S_chan_sync {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my $chan = ${ $_[0] };
 
     if ($self->{awaypoll}) {
@@ -122,22 +134,22 @@ sub S_chan_sync {
 }
 
 sub S_part {
-    my ($self, $irc) = splice @_, 0, 2;
-    my $map   = $irc->isupport('CASEMAPPING');
+    my ($self, undef) = splice @_, 0, 2;
+    my $map   = $self->isupport('CASEMAPPING');
     my $nick  = u_irc((split /!/, ${ $_[0] } )[0], $map);
     my $uchan = u_irc(${ $_[1] }, $map);
 
     if ($nick eq u_irc($self->nick_name(), $map)) {
         delete $self->{STATE}{Nicks}{ $nick }{CHANS}{ $uchan };
         delete $self->{STATE}{Chans}{ $uchan }{Nicks}{ $nick };
-        
+
         for my $member ( keys %{ $self->{STATE}{Chans}{ $uchan }{Nicks} } ) {
             delete $self->{STATE}{Nicks}{ $member }{CHANS}{ $uchan };
             if ( keys %{ $self->{STATE}{Nicks}{ $member }{CHANS} } <= 0 ) {
                 delete $self->{STATE}{Nicks}{ $member };
             }
         }
-        
+
         delete $self->{STATE}{Chans}{ $uchan };
     }
     else {
@@ -147,13 +159,13 @@ sub S_part {
             delete $self->{STATE}{Nicks}{ $nick };
         }
     }
-    
+
     return PCI_EAT_NONE;
 }
 
 sub S_quit {
-    my ($self, $irc) = splice @_, 0, 2;
-    my $map   = $irc->isupport('CASEMAPPING');
+    my ($self, undef) = splice @_, 0, 2;
+    my $map   = $self->isupport('CASEMAPPING');
     my $nick  = (split /!/, ${ $_[0] })[0];
     my $msg   = ${ $_[1] };
     my $unick = u_irc($nick, $map);
@@ -164,18 +176,14 @@ sub S_quit {
     # Check if it is a netsplit
     $netsplit = 1 if _is_netsplit( $msg );
 
-    if ($unick eq u_irc($self->nick_name(), $map)) {
-        delete $self->{STATE};
-        delete $self->{NETSPLIT};
-    }
-    else {
+    if ($unick ne u_irc($self->nick_name(), $map)) {
         for my $uchan ( keys %{ $self->{STATE}{Nicks}{ $unick }{CHANS} } ) {
             delete $self->{STATE}{Chans}{ $uchan }{Nicks}{ $unick };
             # No don't stash the channel state.
             #$self->{NETSPLIT}{Chans}{ $uchan }{NICKS}{ $unick } = $chanstate
             #  if $netsplit;
         }
-        
+
         my $nickstate = delete $self->{STATE}{Nicks}{ $unick };
         if ( $netsplit ) {
           delete $nickstate->{CHANS};
@@ -194,26 +202,26 @@ sub _is_netsplit {
 }
 
 sub S_kick {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my $chan  = ${ $_[1] };
     my $nick  = ${ $_[2] };
-    my $map   = $irc->isupport('CASEMAPPING');
+    my $map   = $self->isupport('CASEMAPPING');
     my $unick = u_irc($nick, $map);
     my $uchan = u_irc($chan, $map);
-    
+
     push @{ $_[-1] }, $self->nick_long_form( $nick );
 
     if ( $unick eq u_irc($self->nick_name(), $map)) {
         delete $self->{STATE}{Nicks}{ $unick }{CHANS}{ $uchan };
         delete $self->{STATE}{Chans}{ $uchan }{Nicks}{ $unick };
-        
+
         for my $member ( keys %{ $self->{STATE}{Chans}{ $uchan }{Nicks} } ) {
             delete $self->{STATE}{Nicks}{ $member }{CHANS}{ $uchan };
             if ( keys %{ $self->{STATE}{Nicks}{ $member }{CHANS} } <= 0 ) {
                 delete $self->{STATE}{Nicks}{ $member };
             }
         }
-        
+
         delete $self->{STATE}{Chans}{ $uchan };
     }
     else {
@@ -223,23 +231,23 @@ sub S_kick {
             delete $self->{STATE}{Nicks}{ $unick };
         }
     }
-    
+
     return PCI_EAT_NONE;
 }
 
 sub S_nick {
-    my ($self, $irc) = splice @_, 0, 2;
+    my $self = shift;
+    $self->SUPER::S_nick(@_);
+    shift @_;
+
     my $nick  = (split /!/, ${ $_[0] })[0];
     my $new   = ${ $_[1] };
-    my $map   = $irc->isupport('CASEMAPPING');
+    my $map   = $self->isupport('CASEMAPPING');
     my $unick = u_irc($nick, $map);
     my $unew  = u_irc($new, $map);
 
     push @{ $_[-1] }, [ $self->nick_channels( $nick ) ];
 
-    # what the baseclass would have done
-    $self->{RealNick} = $new if $nick eq $self->{RealNick};
-
     if ($unick eq $unew) {
         # Case Change
         $self->{STATE}{Nicks}{ $unick }{Nick} = $new;
@@ -247,12 +255,12 @@ sub S_nick {
     else {
         my $user = delete $self->{STATE}{Nicks}{ $unick };
         $user->{Nick} = $new;
-        
+
         for my $channel ( keys %{ $user->{CHANS} } ) {
            $self->{STATE}{Chans}{ $channel }{Nicks}{ $unew } = $user->{CHANS}{ $channel };
            delete $self->{STATE}{Chans}{ $channel }{Nicks}{ $unick };
         }
-        
+
         $self->{STATE}{Nicks}{ $unew } = $user;
     }
 
@@ -260,27 +268,28 @@ sub S_nick {
 }
 
 sub S_chan_mode {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
+    pop @_;
     my $who  = ${ $_[0] };
     my $chan = ${ $_[1] };
     my $mode = ${ $_[2] };
-    my $arg  = ${ $_[3] };
-    my $map  = $irc->isupport('CASEMAPPING');
+    my $arg  = defined $_[3] ? ${ $_[3] } : '';
+    my $map  = $self->isupport('CASEMAPPING');
     my $me   = u_irc($self->nick_name(), $map);
-    
+
     return PCI_EAT_NONE if $mode !~ /\+[qoah]/ || $me ne u_irc($arg, $map);
-    
-    my $excepts = $irc->isupport('EXCEPTS');
-    my $invex = $irc->isupport('INVEX');
-    $irc->yield(mode => $chan, $excepts ) if $excepts;
-    $irc->yield(mode => $chan, $invex ) if $invex;
-    
+
+    my $excepts = $self->isupport('EXCEPTS');
+    my $invex = $self->isupport('INVEX');
+    $self->yield(mode => $chan, $excepts ) if $excepts;
+    $self->yield(mode => $chan, $invex ) if $invex;
+
     return PCI_EAT_NONE;
 }
 
 # RPL_UMODEIS
 sub S_221 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my $mode = ${ $_[1] };
     $mode =~ s/^\+//;
     $self->{STATE}->{usermode} = $mode;
@@ -289,14 +298,14 @@ sub S_221 {
 
 # RPL_UNAWAY
 sub S_305 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     $self->{STATE}->{away} = 0;
     return PCI_EAT_NONE;
 }
 
 # RPL_NOWAWAY
 sub S_306 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     $self->{STATE}->{away} = 1;
     return PCI_EAT_NONE;
 }
@@ -304,8 +313,8 @@ sub S_306 {
 # this code needs refactoring
 ## no critic (Subroutines::ProhibitExcessComplexity ControlStructures::ProhibitCascadingIfElse)
 sub S_mode {
-    my ($self, $irc) = splice @_, 0, 2;
-    my $map   = $irc->isupport('CASEMAPPING');
+    my ($self, undef) = splice @_, 0, 2;
+    my $map   = $self->isupport('CASEMAPPING');
     my $who   = ${ $_[0] };
     my $chan  = ${ $_[1] };
     my $uchan = u_irc($chan, $map);
@@ -314,51 +323,53 @@ sub S_mode {
 
     # CHANMODES is [$list_mode, $always_arg, $arg_when_set, $no_arg]
     # A $list_mode always has an argument
-    my $prefix = $irc->isupport('PREFIX') || { o => '@', v => '+' };
+    my $prefix = $self->isupport('PREFIX') || { o => '@', v => '+' };
     my $statmodes = join '', keys %{ $prefix };
-    my $chanmodes = $irc->isupport('CHANMODES') || [ qw(beI k l imnpstaqr) ];
+    my $chanmodes = $self->isupport('CHANMODES') || [ qw(beI k l imnpstaqr) ];
     my $alwaysarg = join '', $statmodes,  @{ $chanmodes }[0 .. 1];
 
     # Do nothing if it is UMODE
-    if ($uchan ne u_irc($irc->nick_name(), $map)) {
+    if ($uchan ne u_irc($self->nick_name(), $map)) {
         my $parsed_mode = parse_mode_line( $prefix, $chanmodes, @modes );
         for my $mode (@{ $parsed_mode->{modes} }) {
             my $arg;
-            $arg = shift ( @{ $parsed_mode->{args} } ) if ( $mode =~ /^(.[$alwaysarg]|\+[$chanmodes->[2]])/ );
+            if (length $chanmodes->[2] && length $alwaysarg && $mode =~ /^(.[$alwaysarg]|\+[$chanmodes->[2]])/) {
+                $arg = shift @{ $parsed_mode->{args} };
+            }
 
-            $self->_send_event(irc_chan_mode => $who, $chan, $mode, $arg );
+            $self->_send_event(irc_chan_mode => $who, $chan, $mode, (defined $arg ? $arg : ()));
             my $flag;
-            
-            if (($flag) = $mode =~ /\+([$statmodes])/ ) {
+
+            if (length $statmodes && (($flag) = $mode =~ /\+([$statmodes])/)) {
                 $arg = u_irc($arg, $map);
                 if (!$self->{STATE}{Nicks}{ $arg }{CHANS}{ $uchan } || $self->{STATE}{Nicks}{ $arg }{CHANS}{ $uchan } !~ /$flag/) {
                     $self->{STATE}{Nicks}{ $arg }{CHANS}{ $uchan } .= $flag;
                     $self->{STATE}{Chans}{ $uchan }{Nicks}{ $arg } = $self->{STATE}{Nicks}{ $arg }{CHANS}{ $uchan };
                 }
             }
-            elsif (($flag) = $mode =~ /-([$statmodes])/ ) {
+            elsif (length $statmodes && (($flag) = $mode =~ /-([$statmodes])/)) {
                 $arg = u_irc($arg, $map);
                 if ($self->{STATE}{Nicks}{ $arg }{CHANS}{ $uchan } =~ /$flag/) {
                     $self->{STATE}{Nicks}{ $arg }{CHANS}{ $uchan } =~ s/$flag//;
                     $self->{STATE}{Chans}{ $uchan }{Nicks}{ $arg } = $self->{STATE}{Nicks}{ $arg }{CHANS}{ $uchan };
                 }
             }
-            elsif (($flag) = $mode =~ /\+([$chanmodes->[0]])/ ) {
+            elsif (length $chanmodes->[0] && (($flag) = $mode =~ /\+([$chanmodes->[0]])/)) {
                 $self->{STATE}{Chans}{ $uchan }{Lists}{ $flag }{ $arg } = {
                     SetBy => $who,
                     SetAt => time(),
                 };
             }
-            elsif (($flag) = $mode =~ /-([$chanmodes->[0]])/ ) {
+            elsif (length $chanmodes->[0] && (($flag) = $mode =~ /-([$chanmodes->[0]])/)) {
                 delete $self->{STATE}{Chans}{ $uchan }{Lists}{ $flag }{ $arg };
             }
 
             # All unhandled modes with arguments
-            elsif (($flag) = $mode =~ /\+([^$chanmodes->[3]])/ ) {
+            elsif (length $chanmodes->[3] && (($flag) = $mode =~ /\+([^$chanmodes->[3]])/)) {
                 $self->{STATE}{Chans}{ $uchan }{Mode} .= $flag if $self->{STATE}{Chans}{ $uchan }{Mode} !~ /$flag/;
                 $self->{STATE}{Chans}{ $uchan }{ModeArgs}{ $flag } = $arg;
             }
-            elsif (($flag) = $mode =~ /-([^$chanmodes->[3]])/ ) {
+            elsif (length $chanmodes->[3] && (($flag) = $mode =~ /-([^$chanmodes->[3]])/)) {
                 $self->{STATE}{Chans}{ $uchan }{Mode} =~ s/$flag//;
                 delete $self->{STATE}{Chans}{ $uchan }{ModeArgs}{ $flag };
             }
@@ -371,7 +382,7 @@ sub S_mode {
                 $self->{STATE}{Chans}{ $uchan }{Mode} =~ s/$flag//;
             }
         }
-        
+
         # Lets make the channel mode nice
         if ( $self->{STATE}{Chans}{ $uchan }{Mode} ) {
             $self->{STATE}{Chans}{ $uchan }{Mode} = join('', sort {uc $a cmp uc $b} ( split( //, $self->{STATE}{Chans}{ $uchan }{Mode} ) ) );
@@ -395,11 +406,11 @@ sub S_mode {
 }
 
 sub S_topic {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my $who   = ${ $_[0] };
     my $chan  = ${ $_[1] };
     my $topic = ${ $_[2] };
-    my $map   = $irc->isupport('CASEMAPPING');
+    my $map   = $self->isupport('CASEMAPPING');
     my $uchan = u_irc($chan, $map);
 
     $self->{STATE}{Chans}{ $uchan }{Topic} = {
@@ -408,19 +419,19 @@ sub S_topic {
         SetAt => time(),
     };
 
-    return PCI_EAT_NONE;  
+    return PCI_EAT_NONE;
 }
 
 # RPL_NAMES
 sub S_353 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my @data = @{ ${ $_[2] } };
     shift @data if $data[0] =~ /^[@=*]$/;
     my $chan = shift @data;
     my @nicks = split /\s+/, shift @data;
-    my $map   = $irc->isupport('CASEMAPPING');
+    my $map   = $self->isupport('CASEMAPPING');
     my $uchan = u_irc($chan, $map);
-    my $prefix = $irc->isupport('PREFIX') || { o => '@', v => '+' };
+    my $prefix = $self->isupport('PREFIX') || { o => '@', v => '+' };
     my $search = join '|', map { quotemeta } values %$prefix;
     foreach my $user ( @nicks ) {
        my $status;
@@ -440,33 +451,33 @@ sub S_353 {
        $self->{STATE}{Nicks}{ $unick }{CHANS}{ $uchan } = $existing;
        $self->{STATE}{Chans}{ $uchan }{Nicks}{ $unick } = $existing;
     }
-    return PCI_EAT_NONE;  
+    return PCI_EAT_NONE;
 }
 
 # RPL_WHOREPLY
 sub S_352 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my ($chan, $user, $host, $server, $nick, $status, $rest) = @{ ${ $_[2] } };
     my ($hops, $real) = split /\x20/, $rest, 2;
-    my $map   = $irc->isupport('CASEMAPPING');
+    my $map   = $self->isupport('CASEMAPPING');
     my $unick = u_irc($nick, $map);
     my $uchan = u_irc($chan, $map);
 
     $self->{STATE}{Nicks}{ $unick }{Nick} = $nick;
     $self->{STATE}{Nicks}{ $unick }{User} = $user;
     $self->{STATE}{Nicks}{ $unick }{Host} = $host;
-    
+
     if ( !exists $self->{whojoiners} || $self->{whojoiners} ) {
         $self->{STATE}{Nicks}{ $unick }{Hops} = $hops;
         $self->{STATE}{Nicks}{ $unick }{Real} = $real;
         $self->{STATE}{Nicks}{ $unick }{Server} = $server;
         $self->{STATE}{Nicks}{ $unick }{IRCop} = 1 if $status =~ /\*/;
     }
-    
+
     if ( exists $self->{STATE}{Chans}{ $uchan } ) {
         my $whatever = '';
         my $existing = $self->{STATE}{Nicks}{ $unick }{CHANS}{ $uchan } || '';
-        my $prefix = $irc->isupport('PREFIX') || { o => '@', v => '+' };
+        my $prefix = $self->isupport('PREFIX') || { o => '@', v => '+' };
 
         for my $mode ( keys %{ $prefix } ) {
             if ($status =~ /\Q$prefix->{$mode}/ && $existing !~ /\Q$prefix->{$mode}/ ) {
@@ -479,7 +490,7 @@ sub S_352 {
         $self->{STATE}{Chans}{ $uchan }{Nicks}{ $unick } = $existing;
         $self->{STATE}{Chans}{ $uchan }{Name} = $chan;
 
-        if ($self->{STATE}{Chans}{ $uchan }{AWAY_SYNCH} && $unick ne u_irc($irc->nick_name(), $map)) {
+        if ($self->{STATE}{Chans}{ $uchan }{AWAY_SYNCH} && $unick ne u_irc($self->nick_name(), $map)) {
             if ( $status =~ /G/ && !$self->{STATE}{Nicks}{ $unick }{Away} ) {
                 $self->_send_event(irc_user_away => $nick, [ $self->nick_channels( $nick ) ] );
             }
@@ -492,18 +503,19 @@ sub S_352 {
             $self->{STATE}{Nicks}{ $unick }{Away} = $status =~ /G/ ? 1 : 0;
         }
     }
-    
+
     return PCI_EAT_NONE;
 }
 
 # RPL_ENDOFWHO
 sub S_315 {
-    my ($self, $irc) = splice @_, 0, 2;
-    my $chan  = ${ $_[2] }->[0];
-    my $map   = $irc->isupport('CASEMAPPING');
-    my $uchan = u_irc($chan, $map);
+    my ($self, undef) = splice @_, 0, 2;
+    my $what  = ${ $_[2] }->[0];
+    my $map   = $self->isupport('CASEMAPPING');
+    my $uwhat = u_irc($what, $map);
 
-    if ( exists $self->{STATE}{Chans}{ $uchan } ) {
+    if ( exists $self->{STATE}{Chans}{ $uwhat } ) {
+        my $chan = $what; my $uchan = $uwhat;
         if ( $self->_channel_sync($chan, 'WHO') ) {
             my $rec = delete $self->{CHANNEL_SYNCH}{ $uchan };
             $self->_send_event(irc_chan_sync => $chan, time() - $rec->{_time} );
@@ -515,8 +527,9 @@ sub S_315 {
         }
     }
     else {
-        my $nick = shift @{ $self->{NICK_SYNCH}{ $uchan } };
-        delete $self->{NICK_SYNCH}{ $uchan } if !@{ $self->{NICK_SYNCH}{ $uchan } };
+        my $nick = $what; my $unick = $uwhat;
+        my $chan = shift @{ $self->{NICK_SYNCH}{ $unick } };
+        delete $self->{NICK_SYNCH}{ $unick } if !@{ $self->{NICK_SYNCH}{ $unick } };
         $self->_send_event(irc_nick_sync => $nick, $chan );
     }
 
@@ -525,22 +538,22 @@ sub S_315 {
 
 # RPL_CREATIONTIME
 sub S_329 {
-    my ($self, $irc) = splice @_, 0, 2;
-    my $map   = $irc->isupport('CASEMAPPING');
+    my ($self, undef) = splice @_, 0, 2;
+    my $map   = $self->isupport('CASEMAPPING');
     my $chan  = ${ $_[2] }->[0];
     my $time  = ${ $_[2] }->[1];
     my $uchan = u_irc($chan, $map);
-    
+
     $self->{STATE}->{Chans}{ $uchan }{CreationTime} = $time;
     return PCI_EAT_NONE;
 }
 
 # RPL_BANLIST
 sub S_367 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my @args  = @{ ${ $_[2] } };
     my $chan  = shift @args;
-    my $map   = $irc->isupport('CASEMAPPING');
+    my $map   = $self->isupport('CASEMAPPING');
     my $uchan = u_irc($chan, $map);
     my ($mask, $who, $when) = @args;
 
@@ -553,10 +566,10 @@ sub S_367 {
 
 # RPL_ENDOFBANLIST
 sub S_368 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my @args  = @{ ${ $_[2] } };
     my $chan  = shift @args;
-    my $map   = $irc->isupport('CASEMAPPING');
+    my $map   = $self->isupport('CASEMAPPING');
     my $uchan = u_irc($chan, $map);
 
     if ($self->_channel_sync($chan, 'BAN')) {
@@ -569,25 +582,25 @@ sub S_368 {
 
 # RPL_INVITELIST
 sub S_346 {
-    my ($self,$irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my ($chan, $mask, $who, $when) = @{ ${ $_[2] } };
-    my $map   = $irc->isupport('CASEMAPPING');
+    my $map   = $self->isupport('CASEMAPPING');
     my $uchan = u_irc($chan, $map);
-    my $invex = $irc->isupport('INVEX');
+    my $invex = $self->isupport('INVEX');
 
     $self->{STATE}{Chans}{ $uchan }{Lists}{ $invex }{ $mask } = {
         SetBy => $who,
         SetAt => $when
     };
-    
+
     return PCI_EAT_NONE;
 }
 
 # RPL_ENDOFINVITELIST
 sub S_347 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my ($chan) = @{ ${ $_[2] } };
-    my $map    = $irc->isupport('CASEMAPPING');
+    my $map    = $self->isupport('CASEMAPPING');
     my $uchan  = u_irc($chan, $map);
 
     $self->_send_event(irc_chan_sync_invex => $chan);
@@ -596,11 +609,11 @@ sub S_347 {
 
 # RPL_EXCEPTLIST
 sub S_348 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my ($chan, $mask, $who, $when) = @{ ${ $_[2] } };
-    my $map     = $irc->isupport('CASEMAPPING');
+    my $map     = $self->isupport('CASEMAPPING');
     my $uchan   = u_irc($chan, $map);
-    my $excepts = $irc->isupport('EXCEPTS');
+    my $excepts = $self->isupport('EXCEPTS');
 
     $self->{STATE}{Chans}{ $uchan }{Lists}{ $excepts }{ $mask } = {
         SetBy => $who,
@@ -611,25 +624,26 @@ sub S_348 {
 
 # RPL_ENDOFEXCEPTLIST
 sub S_349 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my ($chan) = @{ ${ $_[2] } };
-    my $map    = $irc->isupport('CASEMAPPING');
+    my $map    = $self->isupport('CASEMAPPING');
     my $uchan  = u_irc($chan, $map);
-    
+
     $self->_send_event(irc_chan_sync_excepts => $chan);
     return PCI_EAT_NONE;
 }
 
 # RPL_CHANNELMODEIS
 sub S_324 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my @args  = @{ ${ $_[2] } };
     my $chan  = shift @args;
-    my $map   = $irc->isupport('CASEMAPPING');
+    my $map   = $self->isupport('CASEMAPPING');
     my $uchan = u_irc($chan, $map);
-    my $modes = $irc->isupport('CHANMODES') || [ qw(beI k l imnpstaqr) ];
+    my $modes = $self->isupport('CHANMODES') || [ qw(beI k l imnpstaqr) ];
+    my $prefix = $self->isupport('PREFIX') || { o => '@', v => '+' };
 
-    my $parsed_mode = parse_mode_line( @args );
+    my $parsed_mode = parse_mode_line($prefix, $modes, @args);
     for my $mode (@{ $parsed_mode->{modes} }) {
         $mode =~ s/\+//;
         my $arg = '';
@@ -637,21 +651,21 @@ sub S_324 {
             # doesn't match a mode with no args
             $arg = shift @{ $parsed_mode->{args} };
         }
-        
+
         if ( $self->{STATE}{Chans}{ $uchan }{Mode} ) {
             $self->{STATE}{Chans}{ $uchan }{Mode} .= $mode if $self->{STATE}{Chans}{ $uchan }{Mode} !~ /$mode/;
         }
         else {
             $self->{STATE}{Chans}{ $uchan }{Mode} = $mode;
         }
-        
+
         $self->{STATE}{Chans}{ $uchan }{ModeArgs}{ $mode } = $arg if defined ( $arg );
     }
-    
+
     if ( $self->{STATE}{Chans}{ $uchan }{Mode} ) {
         $self->{STATE}{Chans}{ $uchan }{Mode} = join('', sort {uc $a cmp uc $b} split //, $self->{STATE}{Chans}{ $uchan }{Mode} );
     }
-    
+
     if ( $self->_channel_sync($chan, 'MODE') ) {
         my $rec = delete $self->{CHANNEL_SYNCH}{ $uchan };
         $self->_send_event(irc_chan_sync => $chan, time() - $rec->{_time} );
@@ -662,10 +676,10 @@ sub S_324 {
 
 # RPL_TOPIC
 sub S_332 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my $chan  = ${ $_[2] }->[0];
     my $topic = ${ $_[2] }->[1];
-    my $map   = $irc->isupport('CASEMAPPING');
+    my $map   = $self->isupport('CASEMAPPING');
     my $uchan = u_irc($chan, $map);
 
     $self->{STATE}{Chans}{ $uchan }{Topic}{Value} = $topic;
@@ -674,9 +688,9 @@ sub S_332 {
 
 # RPL_TOPICWHOTIME
 sub S_333 {
-    my ($self, $irc) = splice @_, 0, 2;
+    my ($self, undef) = splice @_, 0, 2;
     my ($chan, $who, $when) = @{ ${ $_[2] } };
-    my $map   = $irc->isupport('CASEMAPPING');
+    my $map   = $self->isupport('CASEMAPPING');
     my $uchan = u_irc($chan, $map);
 
     $self->{STATE}{Chans}{ $uchan }{Topic}{SetBy} = $who;
@@ -696,11 +710,11 @@ sub umode {
 
 sub is_user_mode_set {
     my ($self, $mode) = @_;
-    
+
     $mode = (split //, $mode)[0] || return;
     $mode =~ s/[^A-Za-z]//g;
     return if !$mode;
-    
+
     return 1 if $self->{STATE}{usermode} =~ /$mode/;
     return;
 }
@@ -709,11 +723,11 @@ sub _away_sync {
     my ($self, $chan) = @_[OBJECT, ARG0];
     my $map = $self->isupport('CASEMAPPING');
     my $uchan = u_irc($chan, $map);
-    
+
     $self->{STATE}{Chans}{ $uchan }{AWAY_SYNCH} = 1;
     $self->_send_event(irc_away_sync_start => $chan);
     $self->yield(who => $chan);
-    
+
     return;
 }
 
@@ -775,7 +789,7 @@ sub channels {
             $result{ $self->{STATE}{Chans}{ $uchan }{Name} } = $self->{STATE}{Nicks}{ $unick }{CHANS}{ $uchan };
         }
     }
-    
+
     return \%result;
 }
 
@@ -788,7 +802,7 @@ sub nick_info {
     my ($self, $nick) = @_;
     my $map   = $self->isupport('CASEMAPPING');
     my $unick = u_irc($nick, $map);
-    
+
     return if !$self->_nick_exists($nick);
 
     my $user = $self->{STATE}{Nicks}{ $unick };
@@ -803,9 +817,9 @@ sub nick_long_form {
     my ($self, $nick) = @_;
     my $map   = $self->isupport('CASEMAPPING');
     my $unick = u_irc($nick, $map);
-    
+
     return if !$self->_nick_exists($nick);
-    
+
     my $user = $self->{STATE}{Nicks}{ $unick };
     return "$user->{Nick}!$user->{User}\@$user->{Host}";
 }
@@ -815,7 +829,7 @@ sub nick_channels {
     my $map   = $self->isupport('CASEMAPPING');
     my $unick = u_irc($nick, $map);
 
-    return if !$self->_nick_exists($nick); 
+    return if !$self->_nick_exists($nick);
     return map { $self->{STATE}{Chans}{$_}{Name} } keys %{ $self->{STATE}{Nicks}{ $unick }{CHANS} };
 }
 
@@ -823,7 +837,7 @@ sub channel_list {
     my ($self, $chan) = @_;
     my $map   = $self->isupport('CASEMAPPING');
     my $uchan = u_irc($chan, $map);
-    
+
     return if !$self->_channel_exists($chan);
     return map { $self->{STATE}{Nicks}{$_}{Nick} } keys %{ $self->{STATE}{Chans}{ $uchan }{Nicks} };
 }
@@ -838,7 +852,7 @@ sub is_away {
         return 1 if $self->{STATE}{away};
         return;
     }
-    
+
     return if !$self->_nick_exists($nick);
     return 1 if $self->{STATE}{Nicks}{ $unick }{Away};
     return;
@@ -848,9 +862,9 @@ sub is_operator {
     my ($self, $nick) = @_;
     my $map   = $self->isupport('CASEMAPPING');
     my $unick = u_irc($nick, $map);
-    
+
     return if !$self->_nick_exists($nick);
-    
+
     return 1 if $self->{STATE}{Nicks}{ $unick }{IRCop};
     return;
 }
@@ -868,7 +882,7 @@ sub is_channel_mode_set {
         && $self->{STATE}{Chans}{ $uchan }{Mode} =~ /$mode/) {
         return 1;
     }
-    
+
     return;
 }
 
@@ -884,7 +898,7 @@ sub channel_creation_time {
 
     return if !$self->_channel_exists($chan);
     return if !exists $self->{STATE}{Chans}{ $uchan }{CreationTime};
-    
+
     return $self->{STATE}{Chans}{ $uchan }{CreationTime};
 }
 
@@ -892,7 +906,7 @@ sub channel_limit {
     my ($self, $chan) = @_;
     my $map   = $self->isupport('CASEMAPPING');
     my $uchan = u_irc($chan, $map);
-    
+
     return if !$self->_channel_exists($chan);
 
     if ( $self->is_channel_mode_set($chan, 'l')
@@ -913,7 +927,7 @@ sub channel_key {
         && defined $self->{STATE}{Chans}{ $uchan }{ModeArgs}{k} ) {
         return $self->{STATE}{Chans}{ $uchan }{ModeArgs}{k};
     }
-    
+
     return;
 }
 
@@ -931,7 +945,7 @@ sub channel_modes {
         my %args = %{ $self->{STATE}{Chans}{ $uchan }{ModeArgs} };
         @modes{keys %args} = values %args;
     }
-    
+
     return \%modes;
 }
 
@@ -941,7 +955,7 @@ sub is_channel_member {
     my $uchan = u_irc($chan, $map);
     my $unick = u_irc($nick, $map);
 
-    return if !$self->_channel_exists($chan) || !$self->_nick_exists($nick);    
+    return if !$self->_channel_exists($chan) || !$self->_nick_exists($nick);
     return 1 if defined $self->{STATE}{Chans}{ $uchan }{Nicks}{ $unick };
     return;
 }
@@ -993,7 +1007,7 @@ sub ban_mask {
     for my $nick ( $self->channel_list($chan) ) {
         push @result, $nick if u_irc($self->nick_long_form($nick)) =~ /^$mask$/;
     }
-    
+
     return @result;
 }
 
@@ -1072,7 +1086,8 @@ sub nick_channel_modes {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
@@ -1095,7 +1110,7 @@ nickname and channel tracking
  my @channels = ( '#Blah', '#Foo', '#Bar' );
 
  # We create a new PoCo-IRC object and component.
- my $irc = POE::Component::IRC::State->spawn( 
+ my $irc = POE::Component::IRC::State->spawn(
      nick => $nickname,
      server => $ircserver,
      port => $port,
@@ -1187,17 +1202,17 @@ well as two additional ones:
 
 B<'AwayPoll'>, the interval (in seconds) in which to poll (i.e. C<WHO #channel>)
 the away status of channel members. Defaults to 0 (disabled). If enabled, you
-will receive C<irc_away_sync_*> / L<C<irc_user_away>|/"irc_user_away"> /
-L<C<irc_user_back>|/"irc_user_back"> events, and will be able to use the
-L<C<is_away>|/"is_away"> method for users other than yourself. This can cause
+will receive C<irc_away_sync_*> / L<C<irc_user_away>|/irc_user_away> /
+L<C<irc_user_back>|/irc_user_back> events, and will be able to use the
+L<C<is_away>|/is_away> method for users other than yourself. This can cause
 a lot of increase in traffic, especially if you are on big channels, so if you
 do use this, you probably don't want to set it too low. For reference, X-Chat
 uses 300 seconds (5 minutes).
 
 B<'WhoJoiners'>, a boolean indicating whether the component should send a
 C<WHO nick> for every person which joins a channel. Defaults to on
-(the C<WHO> is sent). If you turn this off, L<C<is_operator>|/"is_operator">
-will not work and L<C<nick_info>|/"nick_info"> will only return the keys
+(the C<WHO> is sent). If you turn this off, L<C<is_operator>|/is_operator>
+will not work and L<C<nick_info>|/nick_info> will only return the keys
 B<'Nick'>, B<'User'>, B<'Host'> and B<'Userhost'>.
 
 =head1 METHODS
@@ -1264,7 +1279,7 @@ channel is not in the state.
 =head2 C<channels>
 
 Takes no parameters. Returns a hashref, keyed on channel name and whether the
-bot is operator, halfop or 
+bot is operator, halfop or
 has voice on that channel.
 
  for my $channel ( keys %{ $irc->channels() } ) {
@@ -1293,7 +1308,7 @@ not have voice on the channel or if the nick/channel does not exist in the state
 Expects a nick as parameter. Returns a true value if the specified nick is away.
 Returns a false value if the nick is not away or not in the state. This will
 only work for your IRC user unless you specified a value for B<'AwayPoll'> in
-L<C<spawn>|POE::Component::IRC/"spawn">.
+L<C<spawn>|POE::Component::IRC/spawn>.
 
 =head2 C<is_channel_admin>
 
@@ -1392,7 +1407,7 @@ L<POE::Component::IRC|POE::Component::IRC> events.
 
 =head3 C<irc_quit>
 
-See also L<C<irc_quit>|POE::Component::IRC/"irc_quit"> in
+See also L<C<irc_quit>|POE::Component::IRC/irc_quit> in
 L<POE::Component::IRC|POE::Component::IRC>.
 
 Additional paramater C<ARG2> contains an arrayref of channel names that are
@@ -1400,7 +1415,7 @@ common to the quitting client and the component.
 
 =head3 C<irc_nick>
 
-See also L<C<irc_nick>|POE::Component::IRC/"irc_nick"> in
+See also L<C<irc_nick>|POE::Component::IRC/irc_nick> in
 L<POE::Component::IRC|POE::Component::IRC>.
 
 Additional parameter C<ARG2> contains an arrayref of channel names that are
@@ -1408,7 +1423,7 @@ common to the nick hanging client and the component.
 
 =head3 C<irc_kick>
 
-See also L<C<irc_kick>|POE::Component::IRC/"irc_kick"> in
+See also L<C<irc_kick>|POE::Component::IRC/irc_kick> in
 L<POE::Component::IRC|POE::Component::IRC>.
 
 Additional parameter C<ARG4> contains the full nick!user@host of the kicked
@@ -1421,9 +1436,9 @@ individual.
 =head3 C<irc_socketerr>
 
 These three all have two additional parameters. C<ARG1> is a hash of
-information about your IRC user (see L<C<nick_info>|/"nick_info">), while
-C<ARG2> is a hash of the channels you were on (see 
-L<C<channels>|/"channels">).
+information about your IRC user (see L<C<nick_info>|/nick_info>), while
+C<ARG2> is a hash of the channels you were on (see
+L<C<channels>|/channels>).
 
 =head2 New events
 
@@ -1434,17 +1449,17 @@ events, there are the following events you can register for:
 
 Sent whenever the component starts to synchronise the away statuses of channel
 members. C<ARG0> is the channel name. You will only receive this event if you
-specified a value for B<'AwayPoll'> in L<C<spawn>|POE::Component::IRC/"spawn">.
+specified a value for B<'AwayPoll'> in L<C<spawn>|POE::Component::IRC/spawn>.
 
 =head3 C<irc_away_sync_end>
 
 Sent whenever the component has completed synchronising the away statuses of
 channel members. C<ARG0> is the channel name. You will only receive this event if
-you specified a value for B<'AwayPoll'> in L<C<spawn>|POE::Component::IRC/"spawn">.
+you specified a value for B<'AwayPoll'> in L<C<spawn>|POE::Component::IRC/spawn>.
 
 =head3 C<irc_chan_mode>
 
-This is almost identical to L<C<irc_mode>|POE::Component::IRC/"irc_mode">,
+This is almost identical to L<C<irc_mode>|POE::Component::IRC/irc_mode>,
 except that it's sent once for each individual mode with it's respective
 argument if it has one (ie. the banmask if it's +b or -b). However, this
 event is only sent for channel modes.
@@ -1478,7 +1493,7 @@ channel they have joined.
 Sent when an IRC user sets his/her status to away. C<ARG0> is the nickname,
 C<ARG1> is an arrayref of channel names that are common to the nickname
 and the component. You will only receive this event if you specified a value
-for B<'AwayPoll'> in L<C<spawn>|POE::Component::IRC/"spawn">.
+for B<'AwayPoll'> in L<C<spawn>|POE::Component::IRC/spawn>.
 
 B<Note:> This above is only for users I<other than yourself>. To know when you
 change your own away status, register for the C<irc_305> and C<irc_306> events.
@@ -1488,14 +1503,14 @@ change your own away status, register for the C<irc_305> and C<irc_306> events.
 Sent when an IRC user unsets his/her away status. C<ARG0> is the nickname,
 C<ARG1> is an arrayref of channel names that are common to the nickname and
 the component. You will only receive this event if you specified a value for
-B<'AwayPoll'> in L<C<spawn>|POE::Component::IRC/"spawn">.
+B<'AwayPoll'> in L<C<spawn>|POE::Component::IRC/spawn>.
 
 B<Note:> This above is only for users I<other than yourself>. To know when you
 change your own away status, register for the C<irc_305> and C<irc_306> events.
 
 =head3 C<irc_user_mode>
 
-This is almost identical to L<C<irc_mode>|POE::Component::IRC/"irc_mode">,
+This is almost identical to L<C<irc_mode>|POE::Component::IRC/irc_mode>,
 except it is sent for each individual umode that is being set.
 
 =head1 CAVEATS
@@ -1506,7 +1521,7 @@ When the component is asked to join a channel, when it joins it will issue
 'WHO #channel', 'MODE #channel', and 'MODE #channel b'. These will solicit
 between them the numerics, C<irc_352>, C<irc_324> and C<irc_329>, respectively.
 When someone joins a channel the bot is on, it issues a 'WHO nick'. You may
-want to ignore these. 
+want to ignore these.
 
 Currently, whenever the component sees a topic or channel list change, it will
 use C<time> for the SetAt value and the full address of the user who set it
@@ -1521,7 +1536,7 @@ should use them with this in mind (for now, at least).
 
 Chris Williams <chris@bingosnet.co.uk>
 
-With contributions from the Kinky Black Goat.
+With contributions from Lyndon Miller.
 
 =head1 LICENCE
 
