@@ -1,18 +1,22 @@
 package POE::Filter::IRC;
+BEGIN {
+  $POE::Filter::IRC::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Filter::IRC::VERSION = '6.54';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use POE::Filter::Stackable;
 use POE::Filter::IRCD;
 use POE::Filter::IRC::Compat;
 
-our $VERSION = '6.08';
-
 sub new {
     my ($package, %opts) = @_;
     $opts{lc $_} = delete $opts{$_} for keys %opts;
     return POE::Filter::Stackable->new(
-        Filters => [ 
+        Filters => [
             POE::Filter::IRCD->new( DEBUG => $opts{debug} ),
             POE::Filter::IRC::Compat->new( DEBUG => $opts{debug} ),
         ],
@@ -20,7 +24,8 @@ sub new {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
